@@ -1,4 +1,5 @@
 package PostScript::File;
+our $VERSION = 0.13;
 use strict;
 use warnings;
 use File::Spec;
@@ -6,7 +7,6 @@ use Sys::Hostname;
 require Exporter;
 our @ISA = qw(Exporter);
 
-our $VERSION = 0.10;
 our @EXPORT_OK = qw(check_tilde check_file incpage_label incpage_roman array_as_string str);
 
 # Prototypes for functions only
@@ -150,46 +150,46 @@ Finally, there are a few stand-alone functions.  These are not methods and are a
 # define page sizes here (a4, letter, etc)
 # should be Properly Cased
 our %size = (
-    A0                    => '2384 3370',
-    A1                    => '1684 2384',
-    A2                    => '1191 1684',
-    A3                    => "841.88976 1190.5512",
-    A4                    => "595.27559 841.88976",
-    A5                    => "420.94488 595.27559",
-    A6                    => '297 420',
-    A7                    => '210 297',
-    A8                    => '148 210',
-    A9                    => '105 148',
+    a0                    => '2384 3370',
+    a1                    => '1684 2384',
+    a2                    => '1191 1684',
+    a3                    => "841.88976 1190.5512",
+    a4                    => "595.27559 841.88976",
+    a5                    => "420.94488 595.27559",
+    a6                    => '297 420',
+    a7                    => '210 297',
+    a8                    => '148 210',
+    a9                    => '105 148',
 
-    B0                    => '2920 4127',
-    B1                    => '2064 2920',
-    B2                    => '1460 2064',
-    B3                    => '1032 1460',
-    B4                    => '729 1032',
-    B5                    => '516 729',
-    B6                    => '363 516',
-    B7                    => '258 363',
-    B8                    => '181 258',
-    B9                    => '127 181 ',
-    B10                   => '91 127',
+    b0                    => '2920 4127',
+    b1                    => '2064 2920',
+    b2                    => '1460 2064',
+    b3                    => '1032 1460',
+    b4                    => '729 1032',
+    b5                    => '516 729',
+    b6                    => '363 516',
+    b7                    => '258 363',
+    b8                    => '181 258',
+    b9                    => '127 181 ',
+    b10                   => '91 127',
 
-    Executive             => '522 756',
-    Folio                 => '595 935',
-    'Half-Letter'         => '612 397',
-    Letter                => "612 792",
-    'US-Letter'           => '612 792',
-    Legal                 => '612 1008',
-    'US-Legal'            => '612 1008',
-    Tabloid               => '792 1224',
-    'SuperB'              => '843 1227',
-    Ledger                => '1224 792',
+    executive             => '522 756',
+    folio                 => '595 935',
+    'half-letter'         => '612 397',
+    letter                => "612 792",
+    'us-letter'           => '612 792',
+    legal                 => '612 1008',
+    'us-legal'            => '612 1008',
+    tabloid               => '792 1224',
+    'superb'              => '843 1227',
+    ledger                => '1224 792',
 
-    'Comm #10 Envelope'   => '297 684',
-    'Envelope-Monarch'    => '280 542',
-    'Envelope-DL'         => '312 624',
-    'Envelope-C5'         => '461 648',
+    'comm #10 envelope'   => '297 684',
+    'envelope-monarch'    => '280 542',
+    'envelope-dl'         => '312 624',
+    'envelope-c5'         => '461 648',
 
-    'EuroPostcard'        => '298 420',
+    'europostcard'        => '298 420',
 );
 
 
@@ -252,9 +252,9 @@ sub new
     };
     bless $o, $class;
 
-    $o->{eps}	     = defined($opt->{eps})	  ? $opt->{eps}	     : 0;
-    $o->{file}	     = defined($opt->{file})	  ? $opt->{file}	     : "";
-    $o->{dir}	     = defined($opt->{dir})	  ? $opt->{dir}	     : "";
+    $o->{eps}	= defined($opt->{eps})	? $opt->{eps}  : 0;
+    $o->{file}	= defined($opt->{file})	? $opt->{file} : "";
+    $o->{dir}	= defined($opt->{dir})	? $opt->{dir}  : "";
     $o->set_paper( $opt->{paper} );
     $o->set_width( $opt->{width} );
     $o->set_height( $opt->{height} );
@@ -333,12 +333,10 @@ This is more convenient when used as a base class.
 
 In addition, the following keys are recognized.  
 
-=head2 File size
+=head2 File size keys
 
 There are four options which control how much gets put into the resulting file.
 
-=over 4
-
 =head3 debug
 
 =over 6
@@ -385,14 +383,10 @@ Requests that a font re-encode function be added and that the 13 standard PostSc
 specified encoding. The only recognized value so far is 'ISOLatin1Encoding' which selects the iso8859-1 encoding and fits most of
 western Europe, including the Scandinavia.
 
-=back
-
-=head2 Initialization
+=head2 Initialization keys
 
 There are a few initialization settings that are only relevant when the file object is constructed.
 
-=over 4
-
 =head3 bottom
 
 The margin in from the paper's bottom edge, specifying the non-printable area.  Remember to specify C<clipping> if
@@ -478,15 +472,11 @@ margin at the top of the page.  Remember to specify C<clipping> if that is what
 
 Set the page width, the shortest edge of the paper.  (Default taken from C<paper>)
 
-=back
-
-=head2 Debugging support 
+=head2 Debugging support keys
 
 This makes most sense in the postscript code rather than perl.  However, it is convenient to be able to set
 defaults for the output position and so on.  See L</"POSTSCRIPT DEBUGGING SUPPORT"> for further details.
 
-=over 4
-
 =head3 db_active
 
 Set to 0 to temporarily suppress the debug output.  (Default: 1)
@@ -508,6 +498,20 @@ routines.  (Default: "0 setgray")
 
 The name of the font to use.  (Default: "Courier")
 
+    Courier
+    Courier-Bold
+    Courier-BoldOblique
+    Courier-Oblique
+    Helvetica
+    Helvetica-Bold
+    Helvetica-BoldOblique
+    Helvetica-Oblique
+    Times-Roman
+    Times-Bold
+    Times-BoldItalic
+    Times-Italic
+    Symbol
+
 =head3 db_fontsize
 
 The size of the font.  Postscript uses its own units, but they are almost points.  (Default: 10)
@@ -529,16 +533,12 @@ The amount indented by C<db_indent>.  (Default: 10)
 
 The top line of debugging output.  Defaults to 6 below the top of the page.
 
-=back
-
-=head2 Error handling
+=head2 Error handling keys
 
 If C<errors> is set, the position of any fatal error message can be controlled with the following options.  Each
 value is placed into a postscript variable of the same name, so they can be overridden from within the code if
 necessary.
 
-=over 4
-
 =head3 errfont
 
 The name of the font used to show the error message.  (Default: "Courier-Bold")
@@ -560,15 +560,11 @@ X position of the error message on the page.  (Default: (72))
 
 Y position of the error message on the page.  (Default: (72))
 
-=back
-
 =head2 Document structure
 
 There are options which only affect the DSC comments.  They all have B<get_> functions which return the
 values set here, e.g. B<get_title> returns the value given to the title option.
 
-=over 4
-
 =head3 extensions
 
 Declare and PostScript language extensions that need to be available.  (No default)
@@ -591,14 +587,10 @@ Set the document's title as recorded in PostScript's Document Structuring Conven
 Set the document's version as recorded in PostScript's Document Structuring Conventions.  This should be a string
 with a major, minor and revision numbers.  For example "1.5 8" signifies revision 8 of version 1.5.  (No default)
 
-=back
-
 =head2 Miscellaneous
 
 A few options that may be changed between pages or set here for the first page.
 
-=over 4
-
 =head3 incpage_handler
 
 Set the initial value for the function which increments page labels.  See L</set_incpage_handler>.
@@ -612,8 +604,6 @@ Set the label (text or number) for the initial page.  See L</set_page_label>.  (
 Set whether the postscript code is filtered.  C<space> strips leading spaces so the user can indent freely
 without increasing the file size.  C<comments> remove lines beginning with '%' as well.  (Default: "space")
 
-=back
-
 =cut
 
 =head1 MAIN METHODS
@@ -1080,19 +1070,6 @@ END_TRAILER
 }
 # Internal method, used by output()
 
-sub print_file ($$) {
-    my($filename, $contents) = @_;
-    if ($filename) {
-	open(OUTFILE, ">", $filename) or die "Unable to write to \'$filename\' : $!\nStopped";
-	print OUTFILE $contents;
-	close OUTFILE;
-    } else {
-	print $contents, "\n";
-    }
-}
-# Internal function, used by output()
-# Expects file name and contents
-
 sub output {
     my ($o, $filename, $dir) = @_;
     $o->set_filename($filename, $dir) if (defined $filename);
@@ -1190,14 +1167,14 @@ END_PAGE_SETUP
 END_PAGE_TRAILER
 	}
 	$postscript .= $o->post_pages();
-	print_file( $psfile, $postscript );
+	return print_file( $psfile, $postscript );
     }
 }
 
 =head2 output( [filename [, dir]] )
 
-Writes the current PostScript out to file.  It is printed to STDOUT if no filename has been given either here, to
-B<new> or B<set_filename>.
+Writes the current PostScript out to the named file provided a filename has been given either here, to
+B<new> or B<set_filename>.  If no filename is given, the text is returned by the function.
 
 Use this option whenever output is required to disk. The current PostScript document in memory is not cleared, and
 can still be extended.
@@ -1276,7 +1253,7 @@ sub get_paper {
 sub set_paper { 
     my $o = shift;
     my $paper = shift || "A4"; 
-    my ($width, $height) = split(/\s+/, $size{ucfirst(lc $paper)});
+    my ($width, $height) = split(/\s+/, $size{lc($paper)});
     if ($height) {
 	$o->{paper} = $paper;
 	$o->{width} = $width;
@@ -2027,8 +2004,6 @@ Judicious use of C<db_active> can help there.
 
 =head3 x0 y0 x1 y1 B<cliptobox>
 
-=over 4
-
 This function is only available if 'clipping' is set.  By calling the perl method B<draw_bounding_box> (and
 resetting with B<clip_bounding_box>) it is possible to use this to identify areas on the page.
 
@@ -2045,15 +2020,11 @@ resetting with B<clip_bounding_box>) it is possible to use this to identify area
 If 'errors' is enabled, this call allows you to report a fatal error from within your postscript code.  It expects
 a string on the stack and it does not return.
 
-=back
-
 All the C<db_> variables (including function names) are defined within their own dictionary (C<debugdict>).  But
 this can be ignored by all calls originating from within code passed to B<add_to_page> (usually including
 B<add_function> code) as the dictionary is automatically put on the stack before each page and taken off as each
 finishes.
 
-=over 4
-
 =head3 any B<db_show>
 
 The workhorse of the system.  This takes the item off the top of the stack and outputs a string representation of
@@ -2147,8 +2118,6 @@ Moves output right by C<db_xtab>.  No stack requirements.  Useful for indenting
 
 Moves output left by C<db_xtab>.  No stack requirements.
 
-=back
-
 =cut
 
 sub draw_bounding_box { 
@@ -2161,6 +2130,21 @@ sub clip_bounding_box {
     $o->{clipcmd} = "clip"; 
 }
 
+### PRIVATE FUNCTIONS
+
+sub print_file ($$) {
+    my($filename, $contents) = @_;
+    if ($filename) {
+	open(OUTFILE, ">", $filename) or die "Unable to write to \'$filename\' : $!\nStopped";
+	print OUTFILE $contents;
+	close OUTFILE;
+    } else {
+	return "$contents\n";
+    }
+}
+# Internal function, used by output()
+# Expects file name and contents
+
 =head1 EXPORTED FUNCTIONS
 
 No functions are exported by default, they must be named as required.
